#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEXT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEXT_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/next.hpp>

#endif
